#
# Copyright 2018-2022 Elyra Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import Any

from airflow.models import BaseOperator


class TestOperatorNoInputs(BaseOperator):
    r"""
    An Operator class with no init function parameters (and hence no
    properties when rendered as a component)
    """

    def __init__(self,
                 *args, **kwargs):

        super().__init__(*args, **kwargs)

    def execute(self, context: Any):
        pass
